@@ -89,7 +89,7 @@ def client_session_info(client):
     try:
         sid = int (sid)
     except:
-        print _("SID error")
+        print _("Invalid SID")
         return 1
     try:
         if sid > 0:
