@@ -23,7 +23,7 @@ import pickle, os
 from calculate.lib.datavars import SourceReadonlyVariable
 
 from calculate.lib.cl_lang import setLocalTranslate
-setLocalTranslate('cl_core',sys.modules[__name__])
+setLocalTranslate('cl_core3',sys.modules[__name__])
 
 ################# API ########################
 class DataVarsSerializer(ClassSerializer):
@@ -41,13 +41,16 @@ class DataVarsSerializer(ClassSerializer):
                   "choice-list":"multichoice",
                   "bool-list":"multichoice",
                   "list":"multichoice_add",
-                  "password":"password"}
+                  "password":"password",
+                  "onepassword":"password",
+                  "need-onepassword":"password",
+                  "need-password":"password"}
         return elementMap.get(typeobj,'input')
 
     def arrayString(self,value):
         if type(value) in (list,tuple):
             return [""] + \
-                map(lambda x:",".join(x) if type(x) in (list,tuple) else x,
+                map(lambda x:",".join(x) if type(x) in (list,tuple) else str(x),
                 value)
         else:
             return value
@@ -151,12 +154,14 @@ class Option(DataVarsSerializer):
     shortopt = String
     longopt = String
     metavalue = String
+    syntax = String
     help = String
 
-    def __init__(self,optlist,metaval,helpval):
+    def __init__(self,optlist,metaval,helpval,syntax=""):
         super(Option,self).__init__()
         self.help = helpval
         self.metavalue = metaval
+        self.syntax = syntax
         for val in optlist:
             if val.startswith('--'):
                 self.longopt=val
@@ -179,7 +184,7 @@ class Field(DataVarsSerializer):
     comments = Array(String)    # comments for choice
 
     def __init__(self,dv=None,varObj=None,expert=False,briefmode=False,
-                 inbrief=False,groupVars=(),**kwargs):
+                 inbrief=False,groupVars=(),onlyhelp=False,**kwargs):
         """
         dv - datavars, varObj - current variable, expert - expert variable flag,
         briefmode - view request for brief, inbrief - variable palced in brief,
@@ -187,41 +192,44 @@ class Field(DataVarsSerializer):
         if dv:
             super(Field,self).__init__()
             self.name = varObj.name
-            self.label = varObj.label or varObj.name
             self.type = varObj.type
             if varObj.opt:
-                self.opt = Option(varObj.opt,varObj.metavalue,varObj.help)
+                self.opt = Option(varObj.opt,varObj.metavalue,varObj.help,
+                                  varObj.syntax)
             self.help = varObj.help
             self.element = varObj.element or \
                            self.elementByType(self.type)
-            if inbrief:
-                self.uncompatible = ""
-            else:
+            if not onlyhelp or varObj.syntax:
+                self.label = varObj.label or varObj.name
+                #if inbrief:
+                #    self.uncompatible = ""
+                #else:
                 self.uncompatible = dv.Uncompatible(varObj.name)
-            if self.uncompatible:
-                for var in varObj.reqUncompat:
-                    if not briefmode and var in groupVars:
-                        if not dv.Uncompatible(var.name):
-                            self.uncompatible = ""
-                            break
-                else:
-                    dv.Invalidate(varObj.name,onlySet=True)
-            if expert:
-                self.default = not varObj.wasSet
-            self.choice, self.comments = self.getChoice(varObj)
-            if self.type == "table":
-                self.tablevalue = Table(dv=dv,briefmode=briefmode,varObj=varObj)
-                if self.tablevalue.writable:
-                    self.type = "writable"
-            else:
-                value = dv.Get(varObj.name)
-                if type(value) == list:
-                    self.listvalue = self.arrayString(value)
-                else:
-                    if briefmode:# and not "choice" in self.type:
-                        self.value = dv.Get(varObj.name,humanreadable=True)
+                if self.uncompatible:
+                    for var in varObj.reqUncompat:
+                        if not briefmode and var in groupVars:
+                            if not dv.Uncompatible(var.name):
+                                self.uncompatible = ""
+                                break
                     else:
-                        self.value = value
+                        dv.Invalidate(varObj.name,onlySet=True)
+                if expert:
+                    self.default = not varObj.wasSet
+                self.choice, self.comments = self.getChoice(varObj)
+                if self.type == "table":
+                    self.tablevalue = Table(dv=dv,briefmode=briefmode,
+                                            varObj=varObj)
+                    if self.tablevalue.writable:
+                        self.type = "writable"
+                else:
+                    value = dv.Get(varObj.name)
+                    if type(value) == list:
+                        self.listvalue = self.arrayString(value)
+                    else:
+                        if briefmode:# and not "choice" in self.type:
+                            self.value = dv.Get(varObj.name,humanreadable=True)
+                        else:
+                            self.value = value
             #if self.value:
             #    self.default = self.value
         else:
@@ -237,13 +245,17 @@ class GroupField(DataVarsSerializer):
 
     def __init__(self,name="",fields=[],prevlabel="",
                  nextlabel="",last=False,dv=None,info=None,
-                 expert=False,brief=False):
+                 expert=False,brief=False,onlyhelp=False):
         super(GroupField,self).__init__()
         self.last = last
         if dv:
             self.name = info['name']
-            self.nextlabel = info['next_label']
-            self.prevlabel = _("Previous")
+            if not onlyhelp:
+                self.nextlabel = info['next_label']
+                self.prevlabel = _("Previous")
+            else:
+                self.nextlabel = None
+                self.prevlabel = None
             self.fields = []
 
             # get all variables with deps which using in this group
@@ -262,7 +274,8 @@ class GroupField(DataVarsSerializer):
                     self.fields.append(Field(dv=dv,inbrief=True,
                                              briefmode = brief,
                                              varObj=varObj,
-                                             groupVars=groupDepVars))
+                                             groupVars=groupDepVars,
+                                             onlyhelp=onlyhelp))
             for varname in info['normal']:
                 inbrief = brief and varname in info['brief']
                 if brief and 'hide' in info and  varname in info['hide']:
@@ -271,7 +284,8 @@ class GroupField(DataVarsSerializer):
                 self.fields.append(Field(dv=dv,inbrief=inbrief,
                                          briefmode = brief,
                                          varObj=varObj,
-                                         groupVars=groupDepVars))
+                                         groupVars=groupDepVars,
+                                         onlyhelp=onlyhelp))
             if info['expert']:
                 for varname in info['expert']:
                     if expert == True or \
@@ -290,16 +304,19 @@ class GroupField(DataVarsSerializer):
                                                inbrief=inbrief,
                                                briefmode = brief,
                                                varObj=varObj,
-                                               groupVars=groupDepVars))
+                                               groupVars=groupDepVars,
+                                               onlyhelp=onlyhelp))
                         break
                 else:
                     if expert == False:
                         for varname in info['expert']:
                             dv.Invalidate(varname,True)
-                    self.fields.append(Field(name = "expert",
-                                 element = "expert",
-                                 label=info['expert_label'],
-                                 value="close"))
+                    if not onlyhelp:
+                        self.fields.append(Field(name = "expert",
+                                     element = "expert",
+                                     label=info['expert_label'],
+                                     value="close",
+                                     onlyhelp=onlyhelp))
         else:
             self.name = name
             self.fields = fields
@@ -310,15 +327,23 @@ class ViewInfo(DataVarsSerializer):
     has_brief = Boolean
 
     def __init__(self,datavars=None,step=None,expert=None,allsteps=False,
-                 brief=None,brief_label=None,has_brief=False,groups=[]):
+                 brief=None,brief_label=None,has_brief=False,groups=[],
+                 viewparams=None):
         super(ViewInfo,self).__init__()
+        onlyhelp = False
+        if viewparams:
+            # for compatible specifing step by param
+            step = viewparams.step if step is None else step
+            expert = viewparams.expert if expert is None else expert
+            brief = viewparams.brief if brief is None else brief
+            onlyhelp = viewparams.onlyhelp
         self.has_brief = has_brief
         if datavars:
             self.groups = []
             varGroups = datavars.getGroups()
             lastGroup = len(varGroups)-1
             # interate all vars group
-            if step in(0,-1,None) or allsteps:
+            if not onlyhelp and (step in(0,-1,None) or allsteps):
                 briefData = datavars.getBrief()
                 self.groups.append(self.stepGroup(varGroups,brief_label,
                             help_value=briefData.get("help",None),
@@ -328,7 +353,7 @@ class ViewInfo(DataVarsSerializer):
                 if step in (None,-1) or step == i:
                     self.groups.append(GroupField(dv=datavars,info=groupInfo,
                                          last=(lastGroup==i),expert=expert,
-                                         brief=brief))
+                                         brief=brief,onlyhelp=onlyhelp))
         else:
             self.groups = groups
 
@@ -359,6 +384,8 @@ class ViewParams(ClassSerializer):
     step = Integer          # number of group variables
     expert = Boolean        # request expert variables
     brief = Boolean         # request brief variables
+    onlyhelp = Boolean      # request params for only help
+    clienttype = String     # type of client "gui","console"
 
 ################# MESSAGE ####################
 
@@ -403,6 +430,48 @@ class CoreWsdl:
     perm_denied = []
     perm_denied.append(Message (type = 'error', message = '403 Forbidden'))
 
+    def callMethod(self,sid,info,logicClass=None,method=None,method_name=None,
+                   callbackRefresh=lambda sid,dv:True):
+        """
+        Common algorithm of method executing
+        """
+        try:
+            dv = self.get_cache(sid,method_name,"vars")
+            if not dv:
+                dv = getattr(self,"%s_vars"%method_name)()
+            else:
+                callbackRefresh(sid,dv)
+                dv.processRefresh()
+            if info:
+                checkonly = info.CheckOnly
+                checkall = info.CheckAll if hasattr(info,"CheckAll") else False
+            else:
+                checkonly = False
+                checkall = False
+            errors = map(lambda x:ReturnedMessage(**x),
+                     dv.checkGroups(info,allvars=checkall or not checkonly))
+            if errors:
+                return errors
+            if checkonly:
+                returnmess = ReturnedMessage(type = '', message = None)
+                return [returnmess]
+            install_meth = type("CommonCore",(self.Common,
+                                logicClass, object), {})
+            pid = self.startprocess(sid, target=install_meth,
+                            method=method,\
+                            method_name=method_name,
+                            args_proc = (dv,))
+            returnmess = ReturnedMessage(type = 'pid', message = pid)
+            returnmess.type = "pid"
+            returnmess.message = pid
+            dv = self.clear_cache(sid,method_name)
+            return [returnmess]
+        finally:
+            if dv:
+                self.set_cache(sid,method_name,"vars",dv,smart=False)
+        return []
+
+
     # verification of compliance certificate and process (pid)
     def check_cert_pid (self, sid, pid):
         import threading
