@@ -104,7 +104,7 @@ def check_server_certificate(cert, key, cert_path, args, port, auto = False):
                 name.ST = ''
             else:
                 name.ST.replace(' ', '_').replace('\t', '_')
-            name.C = raw_input (_('Country (TWO letters only!) [%s]: ') %lang)
+            name.C = raw_input (_('Country (two letters only!) [%s]: ') %lang)
             if not name.C:
                 name.C = lang
 
@@ -153,7 +153,7 @@ def check_server_certificate(cert, key, cert_path, args, port, auto = False):
     elif args.use_root_cert:
         if not os.path.exists(cert_path+'/root.crt'):
             print _('root certificate not found (use cl-core with '
-                    '--gen-root-cert)')
+                    'option --gen-root-cert)')
             return 1
 
         print _('Using the root certificate as the server certificate')
@@ -1185,7 +1185,7 @@ def parse(full=False):
         parser.add_argument(
             '--del-server-req', type=str, dest='id_del_req',
             metavar = 'id_req', help=_("refuse to sign the certificate at "
-                                       "server's request"))
+                                       "the server's request"))
         parser.add_argument(
             '--del-client-req', type=str, dest='id_del_client_req',
             metavar = 'id_req', help=_("decline client's request for signature"))
