@@ -72,8 +72,8 @@ def shortTraceback(e1,e2,e3):
     Return short traceback
     """
     frame = e3
-    for i in apply(traceback.format_exception, (e1,e2,e3)):
-        print i,
+    #for i in apply(traceback.format_exception, (e1,e2,e3)):
+    #    print i,
     while(frame.tb_next):
         frame = frame.tb_next
     module,part = os.path.split(frame.tb_frame.f_code.co_filename)
@@ -632,7 +632,7 @@ class CoreWsdl():
                     lang = list_sid[3]
             fd.close()
         try:
-            if not lang.lower() in ['ru', 'en']:
+            if not lang.lower() in ['fr', 'ru', 'en']:
                 lang = "en"
         except:
                 lang = "en"
