@@ -62,7 +62,7 @@ class BoolAction(argparse.Action):
             elif self.reFalse.match(values):
                 values = "off"
             else:
-                msg = _('value may be on or off')
+                msg = _('the value may be on or off')
                 parser.error(msg)
         setattr(ns, self.dest, values)
 
@@ -540,7 +540,9 @@ def collect_table(field, val_list, client, wait_thread = None,
         for wrong in ifilterfalse(reArgs.search,
                 val_list):
             # raise Error on wrong
-            raise ValueError(_("Wrong value syntax")+" "+wrong)
+            raise ValueError(_("Wrong %s value syntax")%
+                (field.opt.shortopt or field.opt.longopt)
+                +" "+wrong)
         # create groupdict from all vals
         argDict = map(lambda x:x.groupdict(),
                   map(reArgs.search,
@@ -562,7 +564,11 @@ def collect_table(field, val_list, client, wait_thread = None,
     lenChoiceValue = len(choiceValue)
     for wrong in ifilter(lambda x:len(x)>lenChoiceValue,
                  val_table):
-        raise ValueError(_("Wrong value syntax")+" "+wrong)
+        if type(wrong) in (list,tuple):
+            wrong  = ":".join(wrong)
+        raise ValueError(_("Wrong %s value syntax")%
+            (field.opt.shortopt or field.opt.longopt)
+            +" "+wrong)
 
 #    obj_body = []
 
