@@ -389,7 +389,8 @@ def local_method(metaclass, args, unknown_args):
             metaObject.clear_cache(0, method_name)
             return metaObject.method_status
         except (ValueError) as e:
-            colorPrint.printERROR(shortTraceback(*sys.exc_info()))
+            colorPrint.printERROR(str(e))
+            #colorPrint.printERROR(shortTraceback(*sys.exc_info()))
         except (KeyboardInterrupt, EOFError):
             colorPrint.printERROR(_('Manually interrupted'))
         except Exception as e:
