@@ -25,7 +25,7 @@ from calculate.core.server.api_types import (Field, GroupField, ViewInfo,
                                              ViewParams)
 from calculate.lib.datavars import VariableError
 from calculate.lib.cl_lang import getLazyLocalTranslate, setLocalTranslate
-setLocalTranslate('cl_core',sys.modules[__name__])
+setLocalTranslate('cl_core3',sys.modules[__name__])
 
 from calculate.core import datavars
 import traceback
@@ -215,7 +215,7 @@ class CoreWsdl:
     @rpc(Integer, RequestInfo, _returns = Array(ReturnedMessage))
     @Dec.core_method(gui=True, title=__('Show Requests'),category=\
                     __('Utilities'), image='view-certificate-import,'\
-                    'application-certificate',command='cl-core-show-request',
+                    'application-certificate',command='cl-core-request-show',
                     rights=["request"])
     def core_show_request(self, sid, info):
         if not info:
@@ -252,7 +252,7 @@ class CoreWsdl:
     def core_detail_request ( self, sid, info):
         if not info:
             return [ReturnedMessage(type = 'error', field = 'cl_req_id',
-                                    message = 'use -r to select the request')]
+                                    message = "use option -r to select the request")]
 
         dv = datavars.DataVarsCore()
         dv.importCore()
@@ -395,7 +395,7 @@ class CoreWsdl:
 
     @rpc(Integer, DetailRequestInfo, _returns = Array(ReturnedMessage))
     @Dec.core_method(gui=True, title=__('Request confirmation'),
-                     command='cl-core-confirm-request',rights=["request"])
+                     command='cl-core-request-confirm',rights=["request"])
     @catchExcept()
     def core_confirm_request ( self, sid, info):
         dv = self.get_cache(sid,'core_confirm_request',"vars")
@@ -405,7 +405,7 @@ class CoreWsdl:
             dv.flIniFile()
         if not info:
             return [ReturnedMessage(type = 'error', field = 'cl_req_id', \
-                                 message = _('use -r to select the request'))]
+                                 message = _("use option -r to select the request"))]
         try:
             dv.Set('cl_req_id', info.cl_req_id)
         except VariableError, e:
@@ -420,7 +420,7 @@ class CoreWsdl:
 
         if not info.cl_req_group:
             return [ReturnedMessage(type = 'error', field = 'cl_req_group', \
-                       message = _('use -g to select the certificate group'))]
+                       message = _("use option -g to select the certificate group"))]
         try:
             dv.Set('cl_req_group', info.cl_req_group)
         except VariableError, e:
@@ -438,9 +438,9 @@ class CoreWsdl:
             dv = datavars.DataVarsCore()
             dv.importCore()
             dv.flIniFile()
-            dv.Get('cl_req_id')
+            #dv.Get('cl_req_id')
 
-        dv.addGroup(_("Request confirmed"),
+        dv.addGroup(_("Confirm the request"),
             normal=('cl_req_id', 'cl_req_user_name', 'cl_req_ip', 'cl_req_mac',
               'cl_req_date', 'cl_req_location', 'cl_req_group'),
             next_label=_("Done"))
@@ -566,7 +566,7 @@ class CoreWsdl:
         
     @rpc(Integer, DetailRequestInfo, _returns = Array(ReturnedMessage))
     @Dec.core_method(gui=True, title=__('Delete the request'),
-                     command='cl-core-del-request',rights=["request"])
+                     command='cl-core-request-del',rights=["request"])
     @catchExcept()
     def core_del_request ( self, sid, info):
         #dv = self.get_cache(sid,'core_del_request',"vars")
@@ -576,7 +576,7 @@ class CoreWsdl:
         dv.flIniFile()
         if not info:
             return [ReturnedMessage(type = 'error', field = 'cl_req_id', \
-                                 message = _('use -r to select the request'))]
+                                 message = _("use option -r to select the request"))]
         try:
             dv.Set('cl_req_id', info.cl_req_id)
         except VariableError, e:
