@@ -172,7 +172,7 @@ class updateUserConfigs(shareUpdateConfigs):
                        set(self.getConfiguredPasswdUsers()))))
         if not xUsers:
             self.logger.info(_("Package %s") %nameProgram)
-            self.logger.warn(_("X sessions users not found"))
+            self.logger.warn(_("X session users not found"))
             return True
         self.logger.info(_("Package %s") %nameProgram)
         self.logger.info(_("Updating user configuration files"))
